@@ -1,5 +1,5 @@
 
-/* Time-stamp: <2007-11-24 21:44:27 shinya> */
+/* Time-stamp: <2009/06/02 17:18:53 Shinya Abe> */
 
 /*
  *  Cue - A Unit Testing Framework for C, based on CUnit.
@@ -19,6 +19,7 @@
 
 static CU_pSuite suite;
 
+__attribute__((constructor))
 void
 cue_setup()
 {
@@ -33,6 +34,7 @@ cue_register(const char* name, CU_TestFunc test)
   CU_add_test(suite, name, test);
 }
 
+__attribute__((destructor))
 void
 cue_result()
 {
@@ -42,8 +44,8 @@ cue_result()
   CU_basic_set_mode(CU_BRM_VERBOSE);
   CU_basic_run_tests();
   printf("\n");
-/*   CU_basic_show_failures(CU_get_failure_list()); */
-/*   printf("\n"); */
+  /* CU_basic_show_failures(CU_get_failure_list()); */
+  /* printf("\n"); */
 
   n_asserts = CU_get_number_of_asserts();
   n_successes = CU_get_number_of_successes();
