@@ -1,5 +1,5 @@
 
-/* Time-stamp: <2009/05/07 13:15:14 Shinya Abe> */
+/* Time-stamp: <2009/06/02 17:16:47 Shinya Abe> */
 
 /*
  *  Cue - A Unit Testing Framework for C, based on CUnit.
@@ -23,19 +23,6 @@ cue_register(const char* name, CU_TestFunc test);
 void
 cue_result();
 
-#define CU_SETUP() \
-  cue_setup()
-
-#define CU_PROTOTYPE(test) \
-  void test()
-
-#define CU_DEF(test) \
-  void test()
-
-#define CU_REGISTER(name, test) \
-  cue_register(name, test)
-
-#define CU_RUN() \
-  cue_result()
+#define CU_TEST_CASE(test) cue_register(#test, test)
 
 #endif
